@@ -174,6 +174,10 @@ static char *parser_get_next_char(char c, char *str, int qm)
 /** Makes a new tmp buffer out of a substring. */
 static char *make_segment(char *start, char *end)
 {
+#if defined(__GNUC__) && !defined(__clang__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wstringop-truncation"
+#endif
     char *buf, *tmp;
     ptrdiff_t size = (ptrdiff_t)(end - start);
 
@@ -188,6 +192,9 @@ static char *make_segment(char *start, char *end)
     }
 
     return buf;
+#if defined(__GNUC__) && !defined(__clang__)
+#pragma GCC diagnostic pop
+#endif
 }
 
 static char *parser_get_prop_name(char *line, char **end)
@@ -1363,7 +1370,14 @@ char *icalparser_string_line_generator(char *out, size_t buf_size, void *d)
         size = buf_size - 1;
     }
 
+#if defined(__GNUC__) && !defined(__clang__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wstringop-truncation"
+#endif
     strncpy(out, data->pos, size);
+#if defined(__GNUC__) && !defined(__clang__)
+#pragma GCC diagnostic pop
+#endif
 
     if(replace_cr) {
         *(out + size - 1) = '\n';
